@@ -556,6 +556,11 @@ class CommandV(Extensible):
         :return: Request object with the result of the request.
         """
         cfg = self.__config
+        restore_type = ""
+        if cfg.container_config.get('keep_db'):
+            restore_type = 'W_KEEPDB'
+        elif cfg.no_fs:
+            restore_type = 'WO_FILESTORE'
         data = {
             "customer_id": cfg.instance_config.get("customer_id"),
             "task_id": cfg.instance_config.get("task_id"),
@@ -565,6 +570,7 @@ class CommandV(Extensible):
             "current_db_name": cfg.current_db_name,
             "current_db_user": cfg.current_db_user,
             "backup_type": cfg.backup_type,
+            "type": restore_type,
             "backup_path": cfg.backup_src or os.getcwd(),
             "db_password": cfg.instance_config.get("config").get("db_password"),
             "instance_name": cfg.instance_config.get("config").get("container_name"),
@@ -608,10 +614,10 @@ class CommandV(Extensible):
                 'ro': False
                 }
         }
-        postgres_container = res['result'].get('container')
+        postgres_container = self.instance_manager.config.get('postgres_container_name')
         postgres_info = self.instance_manager.inspect(postgres_container)
         db_host = postgres_info.get('NetworkSettings').get('Gateway')
-        db_port = res['result'].get('port')
+        db_port = self.instance_manager.get_db_port(postgres_info)
         self.instance_manager.config.get('env_vars').update({
             'db_host': db_host, 'db_port': db_port, 'external_db_port': db_port})
         self.instance_manager._InstanceV__full_config.instance_config.get('config').update({
