@@ -504,9 +504,13 @@ class DockerV:
         """
         try:
             self.cli.pull(image_name)
-        except docker.errors.NotFound:
-            logger.debug('Image not found in hub')
-            raise errors.NoSuchImage(image_name)
+        except (docker.errors.NotFound, docker.errors.APIError) as error:
+            msg_error = get_error_message(error)
+            if (isinstance(error, docker.errors.NotFound) or
+                    'was deleted or has expired' in msg_error):
+                logger.debug('Image not found in hub')
+                error = errors.NoSuchImage(image_name)
+            raise error
 
     @retry(docker.errors.APIError, tries=3, timeout_secs=0.5, logger=logger)
     def push(self, image_name):
