@@ -355,8 +355,11 @@ def deactivate(ctx, container, database, admin_password, nginx_url):
 @click.option("--migration", is_flag=True, default=False, required=False,
               help=("If true, the deactivated backup is generated in the format"
                     " required by odoo's migration scripts"))
+@click.option("--image-name", help=(
+    "The image where get the deactivate.jinja customer, in example format: "
+    "quay.io/vauxoo/test:test-11.0-stable"))
 def deactivate_backup(ctx, prefix, store_path, backup_src, admin_password,
-                      cformat, upload, remove, nginx_url, no_fs, jobs, migration):
+                      cformat, upload, remove, nginx_url, no_fs, jobs, migration, image_name):
     config_obj = ctx.parent.command.config_parser
     db_config = config_obj.postgres.copy()
     db_config.update({'nginx_url': nginx_url, 'admin': admin_password})
@@ -366,6 +369,7 @@ def deactivate_backup(ctx, prefix, store_path, backup_src, admin_password,
         'remove': remove, 'deactivating_backup': True, 'backup_src': backup_src,
         'cformat': cformat, 'prefix': prefix, 'upload': upload, 'migration': migration})
     default_config['instance']['config'].update(db_config)
+    default_config['container_config'].update({'image_name': image_name})
     config_obj.generate_configuration(default_config)
     command = commandv.CommandV(config_obj)
     try:
