@@ -169,6 +169,7 @@ class DeployvConfig:
         """
         booleans = ['use_template', 'use_nginx', 'rmq_ssl', 'pika_logs']
         integers = ['db_port', 'workers', 'max_instances', 'jobs', 'rmq_port', 'rmq_timeout']
+        lists = ['extensions']
         if not isinstance(config, ConfigParser):
             raise ParameterError('worker_config: Invalid type {}'.format(type(config)))
         for section in config.sections():
@@ -179,6 +180,8 @@ class DeployvConfig:
                         values.update({key: config.getboolean(section, key)})
                     elif key in integers:
                         values.update({key: config.getint(section, key)})
+                    elif key in lists:
+                        values.update({key: json.loads(config.get(section, key))})
             except ValueError as error:
                 error_msg = utils.get_error_message(error)
                 _logger.error('Failed to parse the parameter `%s` of the section `%s`, %s',
