@@ -682,7 +682,7 @@ class InstanceV(DockerV):
                 'db_host': db_host, 'db_port': db_port})
             self.config.get('env_vars').update({
                 'db_port': db_port,
-                'db_host': db_host, 'external_db_port': info})
+                'db_host': db_host, 'external_db_port': db_port})
             return {}
         ins_config = self.config.copy()
         psql_version = self.get_postgres_version()
